@@ -8,9 +8,8 @@ from astropy.io import fits
 
 
 from pyspi.io.get_files import get_files
-from pyspi.io.package_data import get_path_of_external_data_dir, \
-    get_path_of_data_file
-from pyspi.utils.detector_ids import double_names, triple_names
+from pyspi.io.package_data import get_path_of_external_data_dir
+from pyspi.utils.livedets import double_names, triple_names
 from pyspi.utils.function_utils import find_needed_ids, ISDC_MJD_to_cxcsec, \
     get_time_object
 
@@ -22,12 +21,16 @@ from threeML.utils.time_series.binned_spectrum_series import \
 from threeML.utils.spectrum.binned_spectrum import BinnedSpectrumWithDispersion
 from threeML.utils.data_builders.time_series_builder import TimeSeriesBuilder
 
+
 class SPISWFile(object):
     def __init__(self, det, pointing_id, ebounds):
         """
-        Class to read in all the data needed from a SCW file for a given config file
+        Class to read in all the data needed from a SCW file
+        for a given config file
+
         :param config: Config yml filename, Config object or dict
         :param det: For which detector?
+
         """
         # General nameing
         self._det_name = f"Detector {det}"
@@ -61,8 +64,10 @@ class SPISWFile(object):
         """
         Gets all needed information from the data file for the given
         pointing_id
+
         :param pointing_id: pointing_id for which we want the data
-        :return:
+
+        :returns:
         """
 
         with fits.open(os.path.join(get_path_of_external_data_dir(),
@@ -169,7 +174,7 @@ class SPISWFile(object):
     @property
     def geometry_file_path(self):
         """
-        Path to the spacecraft geometry file
+        :returns: Path to the spacecraft geometry file
         """
         return os.path.join(get_path_of_external_data_dir(), 'pointing_data',
                             self._pointing_id, 'sc_orbit_param.fits.gz')
@@ -177,70 +182,70 @@ class SPISWFile(object):
     @property
     def times(self):
         """
-        :return: times of detected events
+        :returns: times of detected events
         """
         return self._times
 
     @property
     def energies(self):
         """
-        :return: energies of detected events
+        :returns: energies of detected events
         """
         return self._energies
 
     @property
     def energy_bins(self):
         """
-        :return: energy bin number of every event
+        :returns: energy bin number of every event
         """
         return self._energy_bins
 
     @property
     def ebounds(self):
         """
-        :return: ebounds of analysis
+        :returns: ebounds of analysis
         """
         return self._ebounds
 
     @property
     def det(self):
         """
-        :return: detector ID
+        :returns: detector ID
         """
         return self._det
 
     @property
     def n_channels(self):
         """
-        :return: number energy channels
+        :returns: number energy channels
         """
         return self._n_channels
 
     @property
     def time_start(self):
         """
-        :return: start time of lightcurve
+        :returns: start time of lightcurve
         """
         return self._time_start
 
     @property
     def time_stop(self):
         """
-        :return: stop time of lightcurve
+        :returns: stop time of lightcurve
         """
         return self._time_stop
 
     @property
     def det_name(self):
         """
-        :return: Name det
+        :returns: Name det
         """
         return self._det_name
 
     @property
     def mission(self):
         """
-        :return: Name Mission
+        :returns: Name Mission
         """
         return self._mission
 
@@ -251,12 +256,14 @@ class SPISWFileGRB(object):
         """
         Class to read in all the data needed from a SCW file for a given
         grbtime
+
         :param det: For which detector?
         :param ebounds: Ebounds for the Analysis.
         :param time_of_grb: Time of the GRB as "YYMMDD HHMMSS"
         :param sgl_type: Which type of single events?
         Only normal sgl, psd or both?
-        :return: Object
+
+        :returns: Object
         """
 
         self._det_name = f"Detector {det}"
@@ -305,8 +312,10 @@ class SPISWFileGRB(object):
         """
         Gets all needed information from the data file for the given
         pointing_id
+
         :param pointing_id: pointing_id for which we want the data
-        :return:
+
+        :returns:
         """
 
         with fits.open(os.path.join(get_path_of_external_data_dir(),
@@ -417,7 +426,8 @@ class SPISWFileGRB(object):
     def _get_deadtime_info(self):
         """
         Get the deadtime info from the hk file
-        :return:
+
+        :returns:
         """
 
         # read in the OB-Time (on-board time) and the ISDC-MJD times
@@ -482,7 +492,7 @@ class SPISWFileGRB(object):
     @property
     def geometry_file_path(self):
         """
-        :return: Path to the spacecraft geometry file
+        :returns: Path to the spacecraft geometry file
         """
         return os.path.join(get_path_of_external_data_dir(),
                             'pointing_data',
@@ -492,77 +502,77 @@ class SPISWFileGRB(object):
     @property
     def times(self):
         """
-        :return: times of detected events
+        :returns: times of detected events
         """
         return self._times
 
     @property
     def energies(self):
         """
-        :return: energies of detected events
+        :returns: energies of detected events
         """
         return self._energies
 
     @property
     def energy_bins(self):
         """
-        :return: energy bin number of every event
+        :returns: energy bin number of every event
         """
         return self._energy_bins
 
     @property
     def ebounds(self):
         """
-        :return: ebounds of analysis
+        :returns: ebounds of analysis
         """
         return self._ebounds
 
     @property
     def det(self):
         """
-        :return: detector ID
+        :returns: detector ID
         """
         return self._det
 
     @property
     def n_channels(self):
         """
-        :return: number energy channels
+        :returns: number energy channels
         """
         return self._n_channels
 
     @property
     def time_start(self):
         """
-        :return: start time of lightcurve
+        :returns: start time of lightcurve
         """
         return self._time_start
 
     @property
     def time_stop(self):
         """
-        :return: stop time of lightcurve
+        :returns: stop time of lightcurve
         """
         return self._time_stop
 
     @property
     def det_name(self):
         """
-        :return: Name det
+        :returns: Name det
         """
         return self._det_name
 
     @property
     def mission(self):
         """
-        :return: Name Mission
+        :returns: Name Mission
         """
         return self._mission
 
     @property
     def deadtime_bin_starts(self):
         """
-        :return: Start time of time bins which have the deadtime
+        :returns: Start time of time bins which have the deadtime
         information
         """
         return self._deadtime_bin_edges[:-1]
@@ -570,7 +580,7 @@ class SPISWFileGRB(object):
     @property
     def deadtime_bin_stops(self):
         """
-        :return: Stop time of time bins which have the deadtime
+        :returns: Stop time of time bins which have the deadtime
         information
         """
         return self._deadtime_bin_edges[1:]
@@ -578,7 +588,7 @@ class SPISWFileGRB(object):
     @property
     def deadtimes_per_interval(self):
         """
-        :return: Deadtime per time bin which have the deadtime
+        :returns: Deadtime per time bin which have the deadtime
         information
         """
         return self._deadtimes
@@ -586,7 +596,7 @@ class SPISWFileGRB(object):
     @property
     def livetimes_per_interval(self):
         """
-        :return: Livetime per time bin which have the deadtime
+        :returns: Livetime per time bin which have the deadtime
         information
         """
         return 1-self._deadtimes
@@ -616,7 +626,7 @@ class TimeSeriesBuilderSPI(TimeSeriesBuilder):
         :param verbose: Verbose?
         :param restore_poly_fit: Path to a file with the poly bkg fits
         :param containter_type: ContainerType for spectrum
-        :return: Object
+        :returns: Object
         """
 
         super(TimeSeriesBuilderSPI, self).__init__(
@@ -635,8 +645,8 @@ class TimeSeriesBuilderSPI(TimeSeriesBuilder):
     def from_spi_grb(cls,
                      name,
                      det,
-                     ebounds,
                      time_of_grb,
+                     ebounds=None,
                      response=None,
                      sgl_type=None,
                      restore_background=None,
@@ -645,6 +655,7 @@ class TimeSeriesBuilderSPI(TimeSeriesBuilder):
     ):
         """
         Class method to build the time_series_builder for a given GRB time
+
         :param name: Name of object
         :param det: Which det?
         :param ebounds: Output ebounds for analysis.
@@ -655,9 +666,22 @@ class TimeSeriesBuilderSPI(TimeSeriesBuilder):
         :param restore_background: File to restore bkg
         :param poly_order: Which poly_order? -1 gives automatic determination
         :param verbose: Verbose?
-        :return: Initalized TimeSeriesBuilder object
+
+        :returns: Initalized TimeSeriesBuilder object
         """
 
+        assert ebounds is not None or response is not None, "You have to "\
+            "either specify ebounds or input a response object."
+
+        if ebounds is not None and response is not None:
+            # check that the ebounds match
+            assert np.all(response.ebounds == ebounds), "Ebounds do not "\
+                "match the ones in the response object!"
+
+        elif response is not None:
+            # ebounds is None in this case
+            ebounds = response.ebounds
+
         # Get an object with all the needed information
         spi_grb_setup = SPISWFileGRB(det,
                                      ebounds,
@@ -699,11 +723,13 @@ class TimeSeriesBuilderSPI(TimeSeriesBuilder):
     ):
         """
         Class method to build the time_series_builder for a given pointing id
+
         :param det: Which det?
         :param ebounds: Output ebounds for analysis.
         :param pointing_id: Pointing ID
         :param response: InstrumenResponse Object
-        :return: Initalized TimeSeriesBuilder object
+
+        :returns: Initalized TimeSeriesBuilder object
         """
 
         spi_grb_setup1 = SPISWFile(det, pointing_id, ebounds)
